@@ -6,20 +6,22 @@ using Makie
 import Makie.SpecApi as S
 
 function ensure_plottrait(PT::Type, arg, desired_plottrait_type::Type)
-    if !(Makie.conversion_trait(PT, arg) isa desired_plottrait_type)
-        error("""
-              `Makie.convert_arguments` for the plot type $PT and its conversion trait $(Makie.conversion_trait(PT, arg)) was unsuccessful.
+    return if !(Makie.conversion_trait(PT, arg) isa desired_plottrait_type)
+        error(
+            """
+            `Makie.convert_arguments` for the plot type $PT and its conversion trait $(Makie.conversion_trait(PT, arg)) was unsuccessful.
 
-              There is a recipe for the given arguments and the `$desired_plottrait_type` trait, however.
+            There is a recipe for the given arguments and the `$desired_plottrait_type` trait, however.
 
-              The signature that could not be converted was:
-              ::$(string(typeof(arg)))
+            The signature that could not be converted was:
+            ::$(string(typeof(arg)))
 
-              Makie needs to convert all plot input arguments to types that can be consumed by the backends (typically Arrays with Float32 elements).
-              You can define a method for `Makie.convert_arguments` (a type recipe) for these types or their supertypes to make this set of arguments convertible (See <https://docs.makie.org/stable/documentation/recipes/index.html>).
+            Makie needs to convert all plot input arguments to types that can be consumed by the backends (typically Arrays with Float32 elements).
+            You can define a method for `Makie.convert_arguments` (a type recipe) for these types or their supertypes to make this set of arguments convertible (See <https://docs.makie.org/stable/documentation/recipes/index.html>).
 
-              Alternatively, you can define `Makie.convert_single_argument` for single arguments which have types that are unknown to Makie but which can be converted to known types and fed back to the conversion pipeline.
-              """)
+            Alternatively, you can define `Makie.convert_single_argument` for single arguments which have types that are unknown to Makie but which can be converted to known types and fed back to the conversion pipeline.
+            """
+        )
     end
 end
 
@@ -32,10 +34,11 @@ end
 Makie.plottype(sol::SciMLBase.AbstractTimeseriesSolution) = Makie.Lines
 
 function Makie.used_attributes(::Type{<:Plot}, sol::SciMLBase.AbstractTimeseriesSolution)
-    (:plot_analytic, :denseplot, :plotdensity, :plotat, :tspan, :tscale, :vars, :idxs)
+    return (:plot_analytic, :denseplot, :plotdensity, :plotat, :tspan, :tscale, :vars, :idxs)
 end
 
-function Makie.convert_arguments(PT::Type{<:Plot},
+function Makie.convert_arguments(
+        PT::Type{<:Plot},
         sol::SciMLBase.AbstractTimeseriesSolution;
         plot_analytic = false,
         denseplot = Makie.automatic,
@@ -44,7 +47,8 @@ function Makie.convert_arguments(PT::Type{<:Plot},
         tspan = nothing,
         tscale = :identity,
         vars = nothing,
-        idxs = nothing)
+        idxs = nothing
+    )
 
     # First, this recipe is specifically only for timeseries solutions.
     # This means that the recipe only applies to `PointBased` plot types.
@@ -61,7 +65,8 @@ function Makie.convert_arguments(PT::Type{<:Plot},
     if vars !== nothing
         Base.depwarn(
             "To maintain consistency with solution indexing, keyword argument vars will be removed in a future version. Please use keyword argument idxs instead.",
-            :f; force = true)
+            :f; force = true
+        )
         (idxs !== nothing) &&
             error("Simultaneously using keywords vars and idxs is not supported. Please only use idxs.")
         idxs = vars
@@ -77,26 +82,34 @@ function Makie.convert_arguments(PT::Type{<:Plot},
         vars = SciMLBase.interpret_vars(idxs, sol)
     end
 
-    # Translate automatics inside the function, for ease of use + passthrough from higher 
+    # Translate automatics inside the function, for ease of use + passthrough from higher
     # level recipes
     if denseplot isa Makie.Automatic
-        denseplot = (sol.dense ||
-                     typeof(sol.prob) <: SciMLBase.AbstractDiscreteProblem) &&
-                    !(typeof(sol) <: SciMLBase.AbstractRODESolution) &&
-                    !(hasfield(typeof(sol), :interp) &&
-                      typeof(sol.interp) <: SciMLBase.SensitivityInterpolation)
+        denseplot = (
+            sol.dense ||
+                typeof(sol.prob) <: SciMLBase.AbstractDiscreteProblem
+        ) &&
+            !(typeof(sol) <: SciMLBase.AbstractRODESolution) &&
+            !(
+            hasfield(typeof(sol), :interp) &&
+                typeof(sol.interp) <: SciMLBase.SensitivityInterpolation
+        )
     end
 
     if plotdensity isa Makie.Automatic
-        plotdensity = min(Int(1e5),
+        plotdensity = min(
+            Int(1.0e5),
             sol.tslocation == 0 ?
-            (sol.prob isa SciMLBase.AbstractDiscreteProblem ?
-             max(1000, 100 * length(sol)) :
-             max(1000, 10 * length(sol))) :
-            1000 * sol.tslocation)
+                (
+                    sol.prob isa SciMLBase.AbstractDiscreteProblem ?
+                    max(1000, 100 * length(sol)) :
+                    max(1000, 10 * length(sol))
+                ) :
+                1000 * sol.tslocation
+        )
     end
 
-    # Originally, in the Plots recipe, `tscale` 
+    # Originally, in the Plots recipe, `tscale`
     # read the axis's `xscale` attribute, and passed that on.
     #
     # However, we can't lift attributes from the axis since
@@ -106,27 +119,33 @@ function Makie.convert_arguments(PT::Type{<:Plot},
 
     # Convert the solution to arrays - this is the hard part!
     plot_vecs,
-    labels = SciMLBase.diffeq_to_arrays(sol, plot_analytic, denseplot,
-        plotdensity, tspan, vars, tscale, plotat)
+        labels = SciMLBase.diffeq_to_arrays(
+        sol, plot_analytic, denseplot,
+        plotdensity, tspan, vars, tscale, plotat
+    )
 
     # We must convert from plot Type to symbol here, for plotspec use
     # since PlotSpecs are defined based on symbols
     plot_type_sym = Makie.plotsym(PT) # TODO this is still a bit hacky!
 
     # Finally, generate a vector of PlotSpecs (one per variable pair)
-    # TODO: broadcast across all input attributes, or figure out how to 
+    # TODO: broadcast across all input attributes, or figure out how to
     # allow customizable colors/labels/etc if required
     makie_plotspecs = if length(plot_vecs) == 2
-        map((x, y, label) -> PlotSpec(plot_type_sym, Point2f.(x, y); label),
+        map(
+            (x, y, label) -> PlotSpec(plot_type_sym, Point2f.(x, y); label),
             eachcol(plot_vecs[1]),
             eachcol(plot_vecs[2]),
-            labels)
+            labels
+        )
     elseif length(plot_vecs) == 3
-        map((x, y, z, label) -> PlotSpec(plot_type_sym, Point3f.(x, y, z); label),
+        map(
+            (x, y, z, label) -> PlotSpec(plot_type_sym, Point3f.(x, y, z); label),
             eachcol(plot_vecs[1]),
             eachcol(plot_vecs[2]),
             eachcol(plot_vecs[3]),
-            labels)
+            labels
+        )
     end
 
     return makie_plotspecs
@@ -139,32 +158,37 @@ end
 Makie.plottype(integrator::SciMLBase.DEIntegrator) = Makie.Lines
 
 function Makie.used_attributes(::Type{<:Plot}, integrator::SciMLBase.DEIntegrator)
-    (:plot_analytic, :denseplot, :plotdensity, :vars, :idxs)
+    return (:plot_analytic, :denseplot, :plotdensity, :vars, :idxs)
 end
 
-function Makie.convert_arguments(PT::Type{<:Makie.Plot},
+function Makie.convert_arguments(
+        PT::Type{<:Makie.Plot},
         integrator::SciMLBase.DEIntegrator;
         plot_analytic = false,
         denseplot = Makie.automatic,
         plotdensity = 10,
         vars = nothing,
-        idxs = nothing)
+        idxs = nothing
+    )
     ensure_plottrait(PT, integrator, Makie.PointBased)
 
     # Interpret keyword arguments
     if vars !== nothing
         Base.depwarn(
             "To maintain consistency with solution indexing, keyword argument vars will be removed in a future version. Please use keyword argument idxs instead.",
-            :f; force = true)
+            :f; force = true
+        )
         (idxs !== nothing) &&
             error("Simultaneously using keywords vars and idxs is not supported. Please only use idxs.")
         idxs = vars
     end
 
     if denseplot isa Makie.Automatic
-        denseplot = (integrator.opts.calck ||
-                     integrator isa AbstractSDEIntegrator) &&
-                    integrator.iter > 0
+        denseplot = (
+            integrator.opts.calck ||
+                integrator isa AbstractSDEIntegrator
+        ) &&
+            integrator.iter > 0
     end
 
     # Begin deconstructing the integrator
@@ -175,10 +199,13 @@ function Makie.convert_arguments(PT::Type{<:Makie.Plot},
         # Generate the points from the plot from dense function
         plott = collect(range(integrator.tprev, integrator.t; length = plotdensity))
         if plot_analytic
-            plot_analytic_timeseries = [integrator.sol.prob.f.analytic(
-                                            integrator.sol.prob.u0,
-                                            integrator.sol.prob.p,
-                                            t) for t in plott]
+            plot_analytic_timeseries = [
+                integrator.sol.prob.f.analytic(
+                        integrator.sol.prob.u0,
+                        integrator.sol.prob.p,
+                        t
+                    ) for t in plott
+            ]
         end
     else
         plott = nothing
@@ -194,7 +221,7 @@ function Makie.convert_arguments(PT::Type{<:Makie.Plot},
         push!(plot_vecs, [])
     end
 
-    labels = String[]# Array{String, 2}(1, length(int_vars)*(1+plot_analytic))
+    labels = String[] # Array{String, 2}(1, length(int_vars)*(1+plot_analytic))
     strs = String[]
     varsyms = SciMLBase.variable_symbols(integrator)
 
@@ -202,7 +229,7 @@ function Makie.convert_arguments(PT::Type{<:Makie.Plot},
         for j in 2:dims
             if denseplot
                 if (x[j] isa Integer && x[j] == 0) ||
-                   isequal(x[j], SciMLBase.getindepsym_defaultt(integrator))
+                        isequal(x[j], SciMLBase.getindepsym_defaultt(integrator))
                     push!(plot_vecs[j - 1], plott)
                 else
                     push!(plot_vecs[j - 1], Vector(integrator(plott; idxs = x[j])))
@@ -232,19 +259,29 @@ function Makie.convert_arguments(PT::Type{<:Makie.Plot},
         for x in int_vars
             for j in 1:dims
                 if denseplot
-                    push!(plot_vecs[j],
-                        u_n(plot_timeseries, x[j], sol, plott, plot_timeseries))
+                    push!(
+                        plot_vecs[j],
+                        u_n(plot_timeseries, x[j], sol, plott, plot_timeseries)
+                    )
                 else # Just get values
                     if x[j] == 0
                         push!(plot_vecs[j], integrator.t)
                     elseif x[j] == 1 && !(integrator.u isa AbstractArray)
-                        push!(plot_vecs[j],
-                            integrator.sol.prob.f(Val{:analytic}, integrator.t,
-                                integrator.sol[1]))
+                        push!(
+                            plot_vecs[j],
+                            integrator.sol.prob.f(
+                                Val{:analytic}, integrator.t,
+                                integrator.sol[1]
+                            )
+                        )
                     else
-                        push!(plot_vecs[j],
-                            integrator.sol.prob.f(Val{:analytic}, integrator.t,
-                                integrator.sol[1])[x[j]])
+                        push!(
+                            plot_vecs[j],
+                            integrator.sol.prob.f(
+                                Val{:analytic}, integrator.t,
+                                integrator.sol[1]
+                            )[x[j]]
+                        )
                     end
                 end
             end
@@ -257,14 +294,20 @@ function Makie.convert_arguments(PT::Type{<:Makie.Plot},
     plot_type_sym = Makie.plotsym(PT)
 
     return if denseplot
-        [Makie.PlotSpec(plot_type_sym,
-             Point2f.(plot_vecs[1][idx], plot_vecs[2][idx]);
-             label,
-             color = Makie.Cycled(idx))
-         for (idx, label) in zip(1:length(plot_vecs[1]), labels)]
+        [
+            Makie.PlotSpec(
+                    plot_type_sym,
+                    Point2f.(plot_vecs[1][idx], plot_vecs[2][idx]);
+                    label,
+                    color = Makie.Cycled(idx)
+                )
+                for (idx, label) in zip(1:length(plot_vecs[1]), labels)
+        ]
     else
-        [S.Scatter([Point2f(plot_vecs[1][idx], plot_vecs[2][idx])]; label)
-         for (idx, label) in zip(1:length(plot_vecs[1]), labels)]
+        [
+            S.Scatter([Point2f(plot_vecs[1][idx], plot_vecs[2][idx])]; label)
+                for (idx, label) in zip(1:length(plot_vecs[1]), labels)
+        ]
     end
 end
 
@@ -275,7 +318,8 @@ Makie.plottype(sol::SciMLBase.AbstractEnsembleSolution) = Makie.Lines
 
 # We also define the attributes that are used by the ensemble solution recipe:
 function Makie.used_attributes(::Type{<:Plot}, sol::SciMLBase.AbstractEnsembleSolution)
-    (:trajectories,
+    return (
+        :trajectories,
         :plot_analytic,
         :denseplot,
         :plotdensity,
@@ -283,10 +327,12 @@ function Makie.used_attributes(::Type{<:Plot}, sol::SciMLBase.AbstractEnsembleSo
         :tspan,
         :tscale,
         :vars,
-        :idxs)
+        :idxs,
+    )
 end
 
-function Makie.convert_arguments(PT::Type{<:Lines},
+function Makie.convert_arguments(
+        PT::Type{<:Lines},
         sim::SciMLBase.AbstractEnsembleSolution;
         trajectories = eachindex(sim),
         plot_analytic = false,
@@ -296,26 +342,31 @@ function Makie.convert_arguments(PT::Type{<:Lines},
         tspan = nothing,
         tscale = :identity,
         vars = nothing,
-        idxs = nothing)
+        idxs = nothing
+    )
 
     # First, we check if the plot type is PointBased, and if not, we throw the standard
     # Makie error message for convert_arguments - just at a different place.
     ensure_plottrait(PT, sim, Makie.PointBased)
 
-    @assert length(trajectories)>0 "No trajectories to plot"
-    @assert length(sim.u)>0 "No solutions to plot"
+    @assert length(trajectories) > 0 "No trajectories to plot"
+    @assert length(sim.u) > 0 "No solutions to plot"
 
     plot_type_sym = Makie.plotsym(PT)
 
-    mp = [PlotSpec(plot_type_sym,
-              sim.u[i];
-              plot_analytic,
-              denseplot,
-              plotdensity,
-              plotat,
-              tspan,
-              tscale,
-              idxs) for i in trajectories]
+    mp = [
+        PlotSpec(
+                plot_type_sym,
+                sim.u[i];
+                plot_analytic,
+                denseplot,
+                plotdensity,
+                plotat,
+                tspan,
+                tscale,
+                idxs
+            ) for i in trajectories
+    ]
 
     # Main.Infiltrator.@infiltrate
 
@@ -329,7 +380,8 @@ end
 Makie.plottype(sim::SciMLBase.EnsembleSummary) = Makie.Lines
 
 function Makie.used_attributes(::Type{<:Lines}, sim::SciMLBase.EnsembleSummary)
-    (:trajectories,
+    return (
+        :trajectories,
         :error_style,
         :ci_type,
         :plot_analytic,
@@ -339,16 +391,19 @@ function Makie.used_attributes(::Type{<:Lines}, sim::SciMLBase.EnsembleSummary)
         :tspan,
         :tscale,
         :vars,
-        :idxs)
+        :idxs,
+    )
 end
 
 # TODO: should `error_style` be Makie plot types instead?  I.e. `Band`, `Errorbar`, etc
-function Makie.convert_arguments(::Type{<:Lines},
+function Makie.convert_arguments(
+        ::Type{<:Lines},
         sim::SciMLBase.EnsembleSummary;
         idxs = sim.u.u[1] isa AbstractArray ? eachindex(sim.u.u[1]) :
-               1,
+            1,
         error_style = :ribbon, ci_type = :quantile,
-        kwargs...)
+        kwargs...
+    )
     if ci_type == :SEM
         if sim.u.u[1] isa AbstractArray
             u = SciMLBase.vecarr_to_vectors(sim.u)
@@ -356,14 +411,26 @@ function Makie.convert_arguments(::Type{<:Lines},
             u = [sim.u.u]
         end
         if sim.u.u[1] isa AbstractArray
-            ci_low = SciMLBase.vecarr_to_vectors(VectorOfArray([sqrt.(sim.v.u[i] /
-                                                                      sim.num_monte) .*
-                                                                1.96
-                                                                for i in 1:length(sim.v)]))
+            ci_low = SciMLBase.vecarr_to_vectors(
+                VectorOfArray(
+                    [
+                        sqrt.(
+                                sim.v.u[i] /
+                                sim.num_monte
+                            ) .*
+                            1.96
+                            for i in 1:length(sim.v)
+                    ]
+                )
+            )
             ci_high = ci_low
         else
-            ci_low = [[sqrt(sim.v.u[i] / length(sim.num_monte)) .* 1.96
-                       for i in 1:length(sim.v)]]
+            ci_low = [
+                [
+                    sqrt(sim.v.u[i] / length(sim.num_monte)) .* 1.96
+                        for i in 1:length(sim.v)
+                ],
+            ]
             ci_high = ci_low
         end
     elseif ci_type == :quantile
@@ -386,18 +453,26 @@ function Makie.convert_arguments(::Type{<:Lines},
     makie_plotlist = Makie.PlotSpec[]
 
     for (count, idx) in enumerate(idxs)
-        push!(makie_plotlist,
-            S.Lines(sim.t, u[idx]; color = Makie.Cycled(count), label = "u[$idx]"))
+        push!(
+            makie_plotlist,
+            S.Lines(sim.t, u[idx]; color = Makie.Cycled(count), label = "u[$idx]")
+        )
         if error_style == :ribbon
-            push!(makie_plotlist,
-                S.Band(sim.t,
+            push!(
+                makie_plotlist,
+                S.Band(
+                    sim.t,
                     u[idx] .- ci_low[idx],
                     u[idx] .+ ci_high[idx];
                     color = Makie.Cycled(count),
-                    alpha = 0.1))
+                    alpha = 0.1
+                )
+            )
         elseif error_style == :bars
-            push!(makie_plotlist,
-                S.Errorbars(sim.t, u[idx], ci_low[idx], ci_high[idx]))
+            push!(
+                makie_plotlist,
+                S.Errorbars(sim.t, u[idx], ci_low[idx], ci_high[idx])
+            )
         elseif error_style == :none
             nothing
         else
