@@ -204,7 +204,7 @@ sol = solve(prob)
 ```
 """
 struct DDEProblem{uType, tType, lType, lType2, isinplace, P, F, H, K, PT} <:
-       AbstractDDEProblem{uType, tType, lType, isinplace}
+    AbstractDDEProblem{uType, tType, lType, isinplace}
     f::F
     u0::uType
     h::H
@@ -217,21 +217,26 @@ struct DDEProblem{uType, tType, lType, lType2, isinplace, P, F, H, K, PT} <:
     order_discontinuity_t0::Int
     problem_type::PT
 
-    @add_kwonly function DDEProblem{iip}(f::AbstractDDEFunction{iip}, u0, h, tspan,
+    @add_kwonly function DDEProblem{iip}(
+            f::AbstractDDEFunction{iip}, u0, h, tspan,
             p = NullParameters();
             constant_lags = (),
             dependent_lags = (),
             neutral = f.mass_matrix !== I &&
-                      det(f.mass_matrix) != 1,
+                det(f.mass_matrix) != 1,
             order_discontinuity_t0 = 0,
             problem_type = StandardDDEProblem(),
-            kwargs...) where {iip}
+            kwargs...
+        ) where {iip}
         _u0 = prepare_initial_state(u0)
         _tspan = promote_tspan(tspan)
         warn_paramtype(p)
-        new{typeof(_u0), typeof(_tspan), typeof(constant_lags), typeof(dependent_lags),
+        new{
+            typeof(_u0), typeof(_tspan), typeof(constant_lags), typeof(dependent_lags),
             isinplace(f),
-            typeof(p), typeof(f), typeof(h), typeof(kwargs), typeof(problem_type)}(f, _u0,
+            typeof(p), typeof(f), typeof(h), typeof(kwargs), typeof(problem_type),
+        }(
+            f, _u0,
             h,
             _tspan,
             p,
@@ -240,38 +245,47 @@ struct DDEProblem{uType, tType, lType, lType2, isinplace, P, F, H, K, PT} <:
             kwargs,
             neutral,
             order_discontinuity_t0,
-            problem_type)
+            problem_type
+        )
     end
 
-    function DDEProblem{iip}(f::AbstractDDEFunction{iip}, h, tspan::Tuple,
+    function DDEProblem{iip}(
+            f::AbstractDDEFunction{iip}, h, tspan::Tuple,
             p = NullParameters();
-            order_discontinuity_t0 = 1, kwargs...) where {iip}
-        DDEProblem{iip}(f, h(p, first(tspan)), h, tspan, p;
-            order_discontinuity_t0 = max(1, order_discontinuity_t0), kwargs...)
+            order_discontinuity_t0 = 1, kwargs...
+        ) where {iip}
+        return DDEProblem{iip}(
+            f, h(p, first(tspan)), h, tspan, p;
+            order_discontinuity_t0 = max(1, order_discontinuity_t0), kwargs...
+        )
     end
 
     function DDEProblem{iip}(f, args...; kwargs...) where {iip}
-        DDEProblem{iip}(DDEFunction{iip}(f), args...; kwargs...)
+        return DDEProblem{iip}(DDEFunction{iip}(f), args...; kwargs...)
     end
 end
 
 function ConstructionBase.constructorof(::Type{P}) where {P <: DDEProblem}
-    function ctor(f, u0, h, tspan, p, constant_lags, dependent_lags,
-            kw, neutral, order_discontinuity_t0, problem_type)
+    return function ctor(
+            f, u0, h, tspan, p, constant_lags, dependent_lags,
+            kw, neutral, order_discontinuity_t0, problem_type
+        )
         if f isa AbstractDDEFunction
             iip = isinplace(f)
         else
             iip = isinplace(f, 5)
         end
-        return DDEProblem{iip}(f, u0, h, tspan, p; kw..., constant_lags, dependent_lags,
-            neutral, order_discontinuity_t0, problem_type)
+        return DDEProblem{iip}(
+            f, u0, h, tspan, p; kw..., constant_lags, dependent_lags,
+            neutral, order_discontinuity_t0, problem_type
+        )
     end
 end
 
 DDEProblem(f, args...; kwargs...) = DDEProblem(DDEFunction(f), args...; kwargs...)
 
 function DDEProblem(f::AbstractDDEFunction, args...; kwargs...)
-    DDEProblem{isinplace(f)}(f, args...; kwargs...)
+    return DDEProblem{isinplace(f)}(f, args...; kwargs...)
 end
 
 SymbolicIndexingInterface.get_history_function(prob::AbstractDDEProblem) = prob.h
@@ -293,20 +307,28 @@ struct DynamicalDDEProblem{iip} <: AbstractDynamicalDDEProblem end
 
 Define a dynamical DDE problem from a [`DynamicalDDEFunction`](@ref).
 """
-function DynamicalDDEProblem(f::DynamicalDDEFunction, v0, u0, h, tspan,
-        p = NullParameters(); dependent_lags = (), kwargs...)
-    DDEProblem(f, ArrayPartition(v0, u0), h, tspan, p;
+function DynamicalDDEProblem(
+        f::DynamicalDDEFunction, v0, u0, h, tspan,
+        p = NullParameters(); dependent_lags = (), kwargs...
+    )
+    return DDEProblem(
+        f, ArrayPartition(v0, u0), h, tspan, p;
         problem_type = DynamicalDDEProblem{isinplace(f)}(),
-        dependent_lags = ntuple(i -> (u, p, t) -> dependent_lags[i](u[1], u[2], p, t),
-            length(dependent_lags)),
-        kwargs...)
+        dependent_lags = ntuple(
+            i -> (u, p, t) -> dependent_lags[i](u[1], u[2], p, t),
+            length(dependent_lags)
+        ),
+        kwargs...
+    )
 end
-function DynamicalDDEProblem(f::DynamicalDDEFunction, h, tspan, p = NullParameters();
-        kwargs...)
-    DynamicalDDEProblem(f, h(p, first(tspan))..., h, tspan, p; kwargs...)
+function DynamicalDDEProblem(
+        f::DynamicalDDEFunction, h, tspan, p = NullParameters();
+        kwargs...
+    )
+    return DynamicalDDEProblem(f, h(p, first(tspan))..., h, tspan, p; kwargs...)
 end
 function DynamicalDDEProblem(f1, f2, args...; kwargs...)
-    DynamicalDDEProblem(DynamicalDDEFunction(f1, f2), args...; kwargs...)
+    return DynamicalDDEProblem(DynamicalDDEFunction(f1, f2), args...; kwargs...)
 end
 
 """
@@ -327,7 +349,7 @@ Define a dynamical DDE problem from the two functions `f1` and `f2`.
 This is determined automatically, but not inferred.
 """
 function DynamicalDDEProblem{iip}(f1, f2, args...; kwargs...) where {iip}
-    DynamicalDDEProblem(DynamicalDDEFunction{iip}(f1, f2), args...; kwargs...)
+    return DynamicalDDEProblem(DynamicalDDEFunction{iip}(f1, f2), args...; kwargs...)
 end
 
 # u'' = f(du,u,h,p,t)
@@ -337,7 +359,7 @@ $(TYPEDEF)
 struct SecondOrderDDEProblem{iip} <: AbstractDynamicalDDEProblem end
 function SecondOrderDDEProblem(f, args...; kwargs...)
     iip = isinplace(f, 6)
-    SecondOrderDDEProblem{iip}(f, args...; kwargs...)
+    return SecondOrderDDEProblem{iip}(f, args...; kwargs...)
 end
 
 """
@@ -361,41 +383,49 @@ This is determined automatically, but not inferred.
 function SecondOrderDDEProblem{iip}(f, args...; kwargs...) where {iip}
     if iip
         f2 = function (du, v, u, h, p, t)
-            du .= v
+            return du .= v
         end
     else
         f2 = function (v, u, h, p, t)
-            v
+            return v
         end
     end
-    DynamicalDDEProblem{iip}(f, f2, args...; problem_type = SecondOrderDDEProblem{iip}(),
-        kwargs...)
+    return DynamicalDDEProblem{iip}(
+        f, f2, args...; problem_type = SecondOrderDDEProblem{iip}(),
+        kwargs...
+    )
 end
 function SecondOrderDDEProblem(f::DynamicalDDEFunction, args...; kwargs...)
     iip = isinplace(f.f1, 6)
     if f.f2.f === nothing
         if iip
             f2 = function (du, v, u, h, p, t)
-                du .= v
+                return du .= v
             end
         else
             f2 = function (v, u, h, p, t)
-                v
+                return v
             end
         end
         return DynamicalDDEProblem(
-            DynamicalDDEFunction{iip}(f.f1, f2;
+            DynamicalDDEFunction{iip}(
+                f.f1, f2;
                 mass_matrix = f.mass_matrix,
-                analytic = f.analytic),
+                analytic = f.analytic
+            ),
             args...; problem_type = SecondOrderDDEProblem{iip}(),
-            kwargs...)
+            kwargs...
+        )
     else
         return DynamicalDDEProblem(
-            DynamicalDDEFunction{iip}(f.f1, f.f2;
+            DynamicalDDEFunction{iip}(
+                f.f1, f.f2;
                 mass_matrix = f.mass_matrix,
-                analytic = f.analytic),
+                analytic = f.analytic
+            ),
             args...; problem_type = SecondOrderDDEProblem{iip}(),
-            kwargs...)
+            kwargs...
+        )
     end
 end
 
@@ -422,9 +452,11 @@ struct DDEAliasSpecifier
     alias_u0::Union{Bool, Nothing}
     alias_tstops::Union{Bool, Nothing}
 
-    function DDEAliasSpecifier(; alias_p = nothing, alias_f = nothing, alias_u0 = nothing,
-            alias_du0 = nothing, alias_tstops = nothing, alias = nothing)
-        if alias == true
+    function DDEAliasSpecifier(;
+            alias_p = nothing, alias_f = nothing, alias_u0 = nothing,
+            alias_du0 = nothing, alias_tstops = nothing, alias = nothing
+        )
+        return if alias == true
             new(true, true, true, true)
         elseif alias == false
             new(false, false, false, false)
