@@ -2,16 +2,16 @@ using BoundaryValueDiffEq, Random
 
 function ode!(du, u, p, t)
     du[1] = u[2]
-    du[2] = -p[1] * u[1]
+    return du[2] = -p[1] * u[1]
 end
 
 function bc!(residual, u, p, t)
     residual[1] = u[1][1] - 1.0
-    residual[2] = u[end][1]
+    return residual[2] = u[end][1]
 end
 
 function prob_func(prob, i, repeat)
-    remake(prob, p = [rand()])
+    return remake(prob, p = [rand()])
 end
 
 initial_guess = [0.0, 1.0]
